const express = require('express');
const https = require('https'); // Use the 'https' module for HTTPS
const fs = require('fs'); // Node.js 'fs' module to read SSL/TLS certificates
const app = express();
const dotenv = require('dotenv');
const cors = require('cors');
dotenv.config();

// Middleware
app.use(express.json());

// Enable CORS for all routes
app.use(cors());

// Connect to MongoDB
require('./config/dbConfig');

// Hospital Routes
const HospitalRoutes = require('./routes/auth/hospitalRoutes');
app.use('/api', HospitalRoutes);

app.use((err, req, res, next) => {
  console.error(err.stack);
  res.status(500).send('Something went wrong!');
});

// app.get('*', (req, res) => {
//   res.sendFile(path.join(__dirname, 'public', 'index.html'));
// });
// Patient Routes
const PatientRoutes = require('./routes/auth/patientRoutes');
app.use('/api', PatientRoutes);

// Shop Routes
const shopRoutes = require('./routes/auth/shopRoutes');
app.use('/api/shop', shopRoutes);

const PORT = process.env.PORT || 5000;

const privateKeyPath = 'path_to_private_key_file.pem'; // Replace with the actual path to your private key file
const certificatePath = 'path_to_certificate_file.pem'; // Replace with the actual path to your certificate file
const caPath = 'path_to_ca_certificate_file.pem'; // Replace with the actual path to your CA certificate file (if applicable)

const privateKey = fs.readFileSync(privateKeyPath, 'utf8');
const certificate = fs.readFileSync(certificatePath, 'utf8');
const ca = fs.readFileSync(caPath, 'utf8'); // Include the CA certificate if you have one

const credentials = {
  key: privateKey,
  cert: certificate,
  ca: ca, // Include the CA certificate if you have one
};

// Create an HTTPS server instance
const httpsServer = https.createServer(credentials, app);

// Listen for incoming connections
httpsServer.listen(PORT, () => {
  console.log(`Server is running on https://backends.letosave.com:${PORT}`);
});
