//middlewares/verifyToken.js

const jwt = require('jsonwebtoken');
const jwtSecret = process.env.JWT_SECRET_KEY;

module.exports = (req, res, next) => {
  try {
    const authHeader = req.headers['authorization'];
    if (!authHeader) {
      return res.status(401).json({ error: 'No token provided' });
    }
    const token = authHeader.split(' ')[1];
    jwt.verify(token, jwtSecret, (err, decodedToken) => {
      if (err) {
        return res.status(403).json({ error: 'Failed to authenticate token' });
      }
      req.decodedToken = decodedToken;
      next();
    });
  } catch (error) {
    console.error('Error verifying JWT token:', error);
    res.status(500).json({ error: 'Internal server error' });
  }
};
