const mongoose = require("mongoose");

const hospitalChatwithAiSchema = new mongoose.Schema({
  hospitalId: {
    type: mongoose.Schema.Types.ObjectId,
    ref: "Hospital",
    required: true,
  },
  chatSessions: [
    {
      chatHistory: [
        {
          time: {
            type: Date,
            default: Date.now,
            required: true,
          },
          content: {
            type: String,
            required: true,
          },
          role: {
            type: String,
            required: true,
            enum: ["user", "assistant", "patient"],
          },
        },
      ],
    },
  ],
});

const HospitalChatwithAi = mongoose.model("HospitalChatwithAi", hospitalChatwithAiSchema);


const patientHospitalChatSchema = new mongoose.Schema({
  sender: {
    id: {
      type: mongoose.Schema.Types.ObjectId,
      required: true,
    },
    type: {
      type: String,
      enum: ["Hospital", "Patient"],
      required: true,
    },
  },
  receiver: {
    id: {
      type: mongoose.Schema.Types.ObjectId,
      required: true,
    },
    type: {
      type: String,
      enum: ["Hospital", "Patient"],
      required: true,
    },
  },
  time: {
    type: Date,
    default: Date.now,
    required: true,
  },
  content: {
    type: String,
    required: true,
  },
});

const PatientHospitalChat = mongoose.model("PatientHospitalChat", patientHospitalChatSchema);


module.exports = { HospitalChatwithAi, PatientHospitalChat };
