const mongoose = require('mongoose');

const hospitalSchema = new mongoose.Schema({
  hospitalName: { type: String },
  isAdmin: {type:Boolean, default:false},
  district: { type: String },
  subCounty: { type: String },
  village: { type: String },
  zipCode: { type: String },
  phone: { type: String },
  phoneOtp: { type: String },
  phoneOtpExpire: { type: Date },
  phoneVerified: { type: Boolean,default: false },
  email: { type: String },
  emailOtp: { type: String },
  emailOtpExpire: { type: String },
  emailVerified: { type: Boolean,default: false },
  certificationImage: { type: String },
  licenseImage: { type: String },
  password: { type: String },
  forgotToken: { type: String },
  forgotTokenExpire: { type: Date },
  balance: { type: Number, default: 0 }
});

const Hospital = mongoose.model('Hospital', hospitalSchema);


const serviceSchema = new mongoose.Schema({
  hospitalId: { type: mongoose.Schema.Types.ObjectId, ref: 'Hospital' }, 
  serviceName: { type: String, required: true },
  wardType: { type: String },
  roomType: { type: String },
  deliveryType: { type: String },
  serviceDescription: { type: String },
  serviceCost: { type: Number },
  doctorFee: { type: Number },
  includePostnatalCare: { type: Boolean, default: false },
});

const Service = mongoose.model('Service', serviceSchema);

const hospitalBankSchema = new mongoose.Schema({
  hospitalId: { type: mongoose.Schema.Types.ObjectId, ref: 'Hospital', required: true },
  accountHoldersName: { type: String, required: true },
  bankCode: { type: String, required: true },
  bankName: { type: String, required: true },
  bankBranch: { type: String, required: true  },
  bankBranchCode: { type: String, required: true  },
  accountNumber: { type: String, required: true },
  phoneNumber: { type: String },
  status: { type: String, default: 'pending' },
  time: { type: Date, default: Date.now },
  errorMessage: { type: String },
  bankCountry: { type: String, required: true  },
  bankAccountCurrency: { type: String, required: true  }, 
  isPrimary: { type: Boolean, default: false }, 
  flutterwaveResponseData: { type: mongoose.Schema.Types.Mixed }
});

const HospitalBank = mongoose.model('HospitalBank', hospitalBankSchema);


const transactionSchema = new mongoose.Schema({
  hospitalId: { type: mongoose.Schema.Types.ObjectId, ref: 'Hospital', required: true },
  hospitalBankId: { type: mongoose.Schema.Types.ObjectId, ref: 'HospitalBank', required: true },
  transDate: { type: Date, required: true, default: Date.now },
  transId: { type: String, required: true },
  amount: { type: Number, required: true }, 
  amountBeforeFee: { type: Number, required: true }, 
  status: { type: String, required: true, default: 'pending' },
  hospitalBalance: { type: Number },
  transferResponse: { type: mongoose.Schema.Types.Mixed },
  transferFeeResponse: { type: mongoose.Schema.Types.Mixed },
});

const Transaction = mongoose.model('Transaction', transactionSchema);


const notificationSchema = new mongoose.Schema({
  title: {
    type: String,
    required: true,
  },
  content: {
    type: String,
    required: true,
  },
  time: {
    type: Date,
    default: Date.now,
  },
  isRead: {
    type: Boolean,
    default: false,
  },
  isReadTime: {
    type: Date,
    default: null,
  },
  isRemove: {
    type: Boolean,
    default: false,
  },
  isRemoveTime: {
    type: Date,
    default: null,
  },
  serviceId: {
    type: mongoose.Schema.Types.ObjectId,
    ref: 'Service',
  },
  transactionId: {
    type: mongoose.Schema.Types.ObjectId,
    ref: 'Transaction',
  },
});

const hospitalNotificationSchema = new mongoose.Schema({
  hospitalId: {
    type: mongoose.Schema.Types.ObjectId,
    ref: 'Hospital', 
    required: true,
  },
  notifications: [notificationSchema],
});

const HospitalNotification = mongoose.model('HospitalNotification', hospitalNotificationSchema);

const commentReviewSchema = new mongoose.Schema({
  rating: { type: Number, min: 1, max: 5, required: true },
  comment: { type: String, required: true },
  patientId: { type: mongoose.Schema.Types.ObjectId, ref: "Patient", required: true },
  hospitalId: { type: mongoose.Schema.Types.ObjectId, ref: "Hospital", required: true },
  isApproved: { type: Boolean, default: false },
  createdAt: { type: Date, default: Date.now },
  updatedAt: { type: Date, default: Date.now },
  deletedAt: { type: Date, default: null },
});

const CommentReview = mongoose.model("CommentReview", commentReviewSchema);

module.exports = { Hospital, Service, HospitalBank, Transaction, HospitalNotification, CommentReview };
