const mongoose = require("mongoose");

const patientSchema = new mongoose.Schema({
  name: {
    type: String,
    required: true,
  },
  email: {
    type: String,
    required: true,
  },
  phone: {
    type: String,
    required: true,
    unique: true,
  },
  password: {
    type: String,
    // required: true,
  },
  phoneOtp: {
    type: String,
  },
  phoneOtpExpire: {
    type: Date,
  },
  isPhoneVerified: {
    type: Boolean,
    default: false,
  },
  forgotToken: {
    type: String,
  },
  forgotTokenExpire: {
    type: Date,
  },
  dateOfBirth: {
    type: Date,
  },
  expectedDelivery: {
    type: Date,
  },
  childsGender: {
    type: String,
  },
  // balance: { type: Number, default: 0 },
  profilePicture: {
    type: String, 
  },
  services: [{
    type: mongoose.Schema.Types.ObjectId,
    ref: 'PatientService'
  }]
});

const Patient = mongoose.model("Patient", patientSchema);

const patientServiceSchema = new mongoose.Schema({
  service: {
    type: mongoose.Schema.Types.ObjectId,
    ref: 'Service', 
    required: true,
  },
  patient: {
    type: mongoose.Schema.Types.ObjectId,
    ref: 'Patient', 
    required: true,
  },
  hospitalId: {
    type: mongoose.Schema.Types.ObjectId,
    ref: 'Hospital', 
  },
  time: {
    type: Date,
    default: Date.now,
  },
  timeResponse: {
    type: Date,
  },
  amountSaved: {
    type: Number,
    default: 0,
  },
  reBalance: {
    type: Number,
    default: 0,
  },
  status: {
    type: String,
    default: "pending",
  },
});
const PatientService = mongoose.model("PatientService", patientServiceSchema);

const patientTransactionSchema = new mongoose.Schema({
  patientId: { type: mongoose.Schema.Types.ObjectId, ref: 'Patient', required: true },
  patientServiceId: { type: mongoose.Schema.Types.ObjectId, ref: 'PatientService', required: true },
  hospitalBankId: { type: mongoose.Schema.Types.ObjectId, ref: 'HospitalBank', required: true },
  hospitalId: { type: mongoose.Schema.Types.ObjectId, ref: 'Hospital', required: true },
  serviceId: { type: mongoose.Schema.Types.ObjectId, ref: 'Service', required: true },
  reBalance: { type: Number, required: true },
  amount: { type: Number, required: true },
  transferId: {type: Number },
  time: { type: Date, required: true, default: Date.now },
  transactionId: { type: String, required: true },
  status: { type: String, required: true, default: 'pending' },
  flutterwaveResponse: { type: mongoose.Schema.Types.Mixed },
  paymentBy: { type: String },
});

const PatientTransaction = mongoose.model('PatientTransaction', patientTransactionSchema);

const notificationSchema = new mongoose.Schema({
  title: {
    type: String,
    required: true,
  },
  content: {
    type: String,
    required: true,
  },
  time: {
    type: Date,
    default: Date.now,
  },
  isRead: {
    type: Boolean,
    default: false,
  },
  isReadTime: {
    type: Date,
    default: null,
  },
  isRemove: {
    type: Boolean,
    default: false,
  },
  isRemoveTime: {
    type: Date,
    default: null,
  },
  serviceId: {
    type: mongoose.Schema.Types.ObjectId,
    ref: 'Service',
  },
  transactionId: {
    type: mongoose.Schema.Types.ObjectId,
    ref: 'Transaction',
  },
});

const patientNotification = new mongoose.Schema({
  patientId: {
    type: mongoose.Schema.Types.ObjectId,
    ref: 'Patient', 
    required: true,
  },
  notifications: [notificationSchema],
});

const PatientNotification = mongoose.model('PatientNotification', patientNotification);

module.exports = { Patient, PatientService, PatientTransaction, PatientNotification };
