const mongoose = require("mongoose");


const productSchema = new mongoose.Schema({
    name: {
      type: String,
      required: true,
    },
    category: {
      type: mongoose.Schema.Types.ObjectId, 
      ref: "Category", 
      required: true,
    },
    subCategory: {
      type: mongoose.Schema.Types.ObjectId, 
      ref: "Subcategory", 
      required: true,
    },
    price: {
      type: Number,
      required: true,
    },
    quantity: {
      type: Number,
      required: true,
    },
    description: {
      type: String,
      required: true,
    },
    image: {
    type: String, 
  },
    createdAt: {
      type: Date,
      default: Date.now,
    },
    updatedAt: {
      type: Date,
      default: null,
    },
    deletedAt: {
      type: Date,
      default: null,
    },
  });

const Product = mongoose.model("Product", productSchema);

const cartSchema = new mongoose.Schema({
  patientId: {
    type: mongoose.Schema.Types.ObjectId,
    required: true,
    unique: true,
    ref: "Patient",
  },
  items: [
    {
      productId: {
        type: mongoose.Schema.Types.ObjectId,
        required: true,
        ref: "Product",
      },
      quantity: {
        type: Number,
        required: true,
        default: 0,
      },
    },
  ],
});

const Cart = mongoose.model("Cart", cartSchema);


const categorySchema = new mongoose.Schema({
    name: {
      type: String,
      required: true,
      unique: true,
    },
  });
  
  const Category = mongoose.model("Category", categorySchema);

  const subcategorySchema = new mongoose.Schema({
    name: {
      type: String,
      required: true,
      unique: true,
    },
    category: {
      type: mongoose.Schema.Types.ObjectId,
      ref: "Category",
      required: true,
    },
  });
  
  const Subcategory = mongoose.model("Subcategory", subcategorySchema);

module.exports = { Product, Cart, Category, Subcategory };
