import * as Core from 'openai/core';
import { APIResource } from 'openai/resource';
import * as API from './index.js';
export declare class Embeddings extends APIResource {
  /**
   * Creates an embedding vector representing the input text.
   */
  create(
    body: EmbeddingCreateParams,
    options?: Core.RequestOptions,
  ): Core.APIPromise<CreateEmbeddingResponse>;
}
export interface CreateEmbeddingResponse {
  /**
   * The list of embeddings generated by the model.
   */
  data: Array<Embedding>;
  /**
   * The name of the model used to generate the embedding.
   */
  model: string;
  /**
   * The object type, which is always "embedding".
   */
  object: string;
  /**
   * The usage information for the request.
   */
  usage: CreateEmbeddingResponse.Usage;
}
export declare namespace CreateEmbeddingResponse {
  /**
   * The usage information for the request.
   */
  interface Usage {
    /**
     * The number of tokens used by the prompt.
     */
    prompt_tokens: number;
    /**
     * The total number of tokens used by the request.
     */
    total_tokens: number;
  }
}
/**
 * Represents an embedding vector returned by embedding endpoint.
 */
export interface Embedding {
  /**
   * The embedding vector, which is a list of floats. The length of vector depends on
   * the model as listed in the [embedding guide](/docs/guides/embeddings).
   */
  embedding: Array<number>;
  /**
   * The index of the embedding in the list of embeddings.
   */
  index: number;
  /**
   * The object type, which is always "embedding".
   */
  object: string;
}
export interface EmbeddingCreateParams {
  /**
   * Input text to embed, encoded as a string or array of tokens. To embed multiple
   * inputs in a single request, pass an array of strings or array of token arrays.
   * Each input must not exceed the max input tokens for the model (8191 tokens for
   * `text-embedding-ada-002`).
   * [Example Python code](https://github.com/openai/openai-cookbook/blob/main/examples/How_to_count_tokens_with_tiktoken.ipynb)
   * for counting tokens.
   */
  input: string | Array<string> | Array<number> | Array<Array<number>>;
  /**
   * ID of the model to use. You can use the
   * [List models](/docs/api-reference/models/list) API to see all of your available
   * models, or see our [Model overview](/docs/models/overview) for descriptions of
   * them.
   */
  model: (string & {}) | 'text-embedding-ada-002';
  /**
   * A unique identifier representing your end-user, which can help OpenAI to monitor
   * and detect abuse. [Learn more](/docs/guides/safety-best-practices/end-user-ids).
   */
  user?: string;
}
export declare namespace Embeddings {
  export import CreateEmbeddingResponse = API.CreateEmbeddingResponse;
  export import Embedding = API.Embedding;
  export import EmbeddingCreateParams = API.EmbeddingCreateParams;
}
//# sourceMappingURL=embeddings.d.ts.map
