
const path = require("path");
const ejs = require("ejs");
const nodemailer = require("nodemailer");

const emailTemplatePath = path.join(
  __dirname,
  "../helpers/emailTemplate.ejs"
);

async function sendPasswordResetEmail(email, resetLink) {
  try {
    const transporter = nodemailer.createTransport({
      host: "smtp.gmail.com",
      port: 587,
      secure: false,
      auth: {
        user: process.env.EMAIL_USERNAME,
        pass: process.env.EMAIL_PASSWORD,
      },
    });

    const emailTemplate = await ejs.renderFile(emailTemplatePath, {
      resetUrl: resetLink,
    });

    const mailOptions = {
      from: process.env.EMAIL_USERNAME,
      to: email,
      subject: "Password Reset",
      html: emailTemplate,
    };

    await transporter.sendMail(mailOptions);
  } catch (error) {
    console.error(
      "Error occurred while sending the password reset email:",
      error
    );
    throw new Error("Email sending failed.");
  }
}

module.exports = sendPasswordResetEmail;
